@@ -180,9 +180,9 @@ NMEA_MSGIDS = {
     "RMB": "Recommended Navigation data for GPS",
     "RMC": "Recommended Minimum data",
     "RTE": "Route message",
-    "TRF": "Transit Fix Data",
     "STN": "Multiple Data ID",
-    "THS": "TRUE Heading and Status",
+    "THS": "True Heading and Status",
+    "TRF": "Transit Fix Data",
     "TXT": "Text Transmission",
     "VBW": "Dual Ground / Water Speed",
     "VLW": "Dual Ground Water Distance",
